import requests
import re
import argparse
import os
import subprocess


def is_replace(connector_name, compatible_version):
    compatible_version = compatible_version.strip()

    if compatible_version == 'ALL':
        return True

    if compatible_version == 'NULL':
        return False

    if not re.compile(r"[0-9]+.[0-9]+.[0-9]+$").match(compatible_version):
        raise Exception('Incorrect Compatible Version Information')
    response = requests.get('https://localhost:9595/integration/connectors/?format=json&name='+connector_name, verify=False,
                             headers={'Content-Type': 'application/json'})
    if response.ok:
        connectors = response.json()['data']
        compatible_version_map = tuple(map(int, (compatible_version.split("."))))
        for connector in connectors:
            name = connector['name']
            version = connector['version']
            if tuple(map(int, (version.split(".")))) < compatible_version_map:
                return False
        return True
    raise Exception('Failed to validate against installed connectors')


def import_connector(connector_name, compatible_version):
    # create request with file
    url = 'https://localhost:9595/integration/import-connector/' + connector_name + '/?replace=' + \
          str(is_replace(connector_name, compatible_version)) + '&rpm_installed=true'
    with open('/opt/cyops-connector-' + connector_name + '/' + connector_name+ '.tgz', 'rb') as payload:
        import_response = requests.post(url, data=payload, verify=False)


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Import Connectors')
    parser.add_argument('--name', type=str, help='Name of the Connector to Import', required=True)
    parser.add_argument('--compatibility', type=str, help='Oldest Compatible Version Of the Connector', required=True)
    args = parser.parse_args()
    os.environ['NO_PROXY'] = 'localhost'
    import_connector(args.name, args.compatibility)
